@@ -1,4 +1,5 @@
 import cv2
+import multiprocessing as mp
 from monkey_vision.app.utils.group_points import group_coordinates
 from monkey_vision.app import vision_points, vision_compare
 # from dev import dev as DEV
@@ -25,14 +26,16 @@ def get_event_points(imageURI, isDev=False):
     return groups
 
 
-def percengate_compare(imageURI, compareImageURI):
-    if imageURI is None or compareImageURI is None:
+def percengate_compare(*args):
+    """
+    Method to calculate the percentage match of a provided array of images. 
+    Will run parallely the percentage compare and return the results.
+    args[0] base image path. To be matched with all the rest of the provided image paths.
+    @returns array of percentage matches
+    """
+    if args[0] is None or args[1] is None:
         return
-    percengate = vision_compare.get_percentage_match(imageURI, compareImageURI)
-    return percengate
-
-
-# points = get_event_points(imageURI, isDev=True)
-# print(points)
-# perc = percengate_compare(imageURI, imageURICompare)
-# print(perc, "%")
+    pool = mp.Pool(mp.cpu_count())
+    results = [pool.apply(vision_compare.get_percentage_match, args=(args[0], item)) for item in args[1:]]
+    pool.close()   
+    return results
